@@ -1,255 +1,286 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="el_GR">
+<TS version="2.1" language="el">
 <context>
     <name>MainWindow</name>
     <message>
         <location filename="../mainwindow.ui" line="14"/>
         <source>MX Codecs Installer</source>
-        <translation type="unfinished"></translation>
+        <translation>MX Εγκατάσταση κωδικοποιητών</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="27"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some jurisdictions, their distribution may be limited. Please check the regulations in your area. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;Με την εφαρμογή αυτή θα μπορέσετε να εγκαταστήσετε κωδικοποιητές, που επιτρέπουν προηγμένες λειτουργίες βίντεο και ήχου αλλά με περιορισμούς.&lt;/ p&gt;&lt;p align=&quot;justify&quot;&gt;Σε ορισμένες περιοχές, η διανομή τους μπορεί να περιορίζεται από τοπικούς κανονισμούς. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt; Αναλαμβάνετε την ευθύνη για τη λήψη αυτών των κωδικοποιητών;&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="44"/>
         <source>Downloading codecs files</source>
-        <translation type="unfinished"></translation>
+        <translation>Λήψη αρχείων κωδικοποιητών</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="100"/>
         <source>Cancel any changes then quit</source>
-        <translation type="unfinished"></translation>
+        <translation>Ακύρωση κάθε αλλαγών και κλείσιμο</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="103"/>
         <source>Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>Άκυρο</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="110"/>
         <source>Alt+N</source>
-        <translation type="unfinished"></translation>
+        <translation>Alt+N</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="129"/>
         <source>Begin codec download and installation</source>
-        <translation type="unfinished"></translation>
+        <translation>Έναρξη λήψης και εγκατάστασης κωδικοποιητή</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="132"/>
         <source>OK</source>
-        <translation type="unfinished"></translation>
+        <translation>Εντάξει</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="193"/>
         <source>About this application</source>
-        <translation type="unfinished"></translation>
+        <translation>Περί της εφαρμογής</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="196"/>
         <source>About...</source>
-        <translation type="unfinished"></translation>
+        <translation>Περί...</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="203"/>
         <source>Alt+B</source>
-        <translation type="unfinished"></translation>
+        <translation>Alt+B</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="232"/>
         <source>Display help </source>
-        <translation type="unfinished"></translation>
+        <translation>Εμφάνιση βοήθειας </translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="235"/>
         <source>Help</source>
-        <translation type="unfinished"></translation>
+        <translation>Βοήθεια</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="242"/>
         <source>Alt+H</source>
-        <translation type="unfinished"></translation>
+        <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="105"/>
-        <location filename="../mainwindow.cpp" line="146"/>
-        <location filename="../mainwindow.cpp" line="166"/>
-        <location filename="../mainwindow.cpp" line="209"/>
-        <location filename="../mainwindow.cpp" line="218"/>
-        <location filename="../mainwindow.cpp" line="241"/>
-        <location filename="../mainwindow.cpp" line="282"/>
+        <location filename="../mainwindow.cpp" line="184"/>
+        <location filename="../mainwindow.cpp" line="191"/>
+        <location filename="../mainwindow.cpp" line="200"/>
+        <location filename="../mainwindow.cpp" line="226"/>
+        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
+        <translation>&lt;b&gt;Η εντολή εκτελείται...&lt;/b&gt;&lt;p&gt;</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="110"/>
+        <location filename="../mainwindow.cpp" line="151"/>
+        <location filename="../mainwindow.cpp" line="171"/>
+        <location filename="../mainwindow.cpp" line="214"/>
+        <location filename="../mainwindow.cpp" line="223"/>
+        <location filename="../mainwindow.cpp" line="246"/>
+        <location filename="../mainwindow.cpp" line="287"/>
         <source>Error</source>
-        <translation type="unfinished"></translation>
+        <translation>Σφάλμα</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="106"/>
+        <location filename="../mainwindow.cpp" line="214"/>
+        <source>Cannot connect to the download site</source>
+        <translation>Δεν είναι δυνατή η σύνδεση με την τοποθεσία λήψης</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="126"/>
+        <source>Error downloading %1</source>
+        <translation>Σφάλμα στη λήψη %1</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="111"/>
         <source>Internet is not available, won&apos;t be able to download the list of packages</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="121"/>
-        <source>Error downloading %1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="147"/>
+        <location filename="../mainwindow.cpp" line="152"/>
         <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="166"/>
+        <location filename="../mainwindow.cpp" line="171"/>
         <source>Could not create temp directory. </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="179"/>
-        <location filename="../mainwindow.cpp" line="186"/>
-        <location filename="../mainwindow.cpp" line="195"/>
-        <location filename="../mainwindow.cpp" line="221"/>
-        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="179"/>
+        <location filename="../mainwindow.cpp" line="184"/>
         <source>downloading Packages.gz from &apos;main&apos;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="186"/>
+        <location filename="../mainwindow.cpp" line="191"/>
         <source>downloading Packages.gz from &apos;non-free&apos;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="195"/>
+        <location filename="../mainwindow.cpp" line="200"/>
         <source>downloading Packages.gz from i386 &apos;main&apos;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="201"/>
+        <location filename="../mainwindow.cpp" line="206"/>
         <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;b&gt;H λήψη oλοκληρώθηκε.&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="209"/>
-        <source>Cannot connect to the download site</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="218"/>
+        <location filename="../mainwindow.cpp" line="223"/>
         <source>Cannot connect find %1 package</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="238"/>
+        <location filename="../mainwindow.cpp" line="243"/>
         <source>Installing downloaded files</source>
-        <translation type="unfinished"></translation>
+        <translation>Εγκατάσταση ληφθέντων αρχείων</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="241"/>
+        <location filename="../mainwindow.cpp" line="246"/>
         <source>No downloaded *.debs files found.</source>
-        <translation type="unfinished"></translation>
+        <translation>Δεν βρέθηκαν αρχεία *.debs.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="259"/>
+        <location filename="../mainwindow.cpp" line="264"/>
         <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="261"/>
-        <source>Error installing %1</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;b&gt;Εγκατάσταση...&lt;/b&gt;&lt;p&gt;</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="266"/>
-        <source>Fix missing dependencies...</source>
-        <translation type="unfinished"></translation>
+        <source>Error installing %1</source>
+        <translation>Σφάλμα κατά την εγκατάσταση %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="269"/>
-        <source>Error running %1 command</source>
-        <translation type="unfinished"></translation>
+        <location filename="../mainwindow.cpp" line="271"/>
+        <source>Fix missing dependencies...</source>
+        <translation>Επίλυση εξαρτήσεων...</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="274"/>
-        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="278"/>
-        <source>Finished</source>
-        <translation type="unfinished"></translation>
+        <source>Error running %1 command</source>
+        <translation>Σφάλμα κατά την εκτέλεση της εντολής %1</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="279"/>
+        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
+        <translation>&lt;b&gt;H διαδικασία εγκατάστασης έχει ολοκληρωθεί&lt;/b&gt;</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="283"/>
+        <source>Finished</source>
+        <translation>Ολοκληρώθηκε</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="284"/>
         <source>Codecs files have been downloaded and installed successfully.</source>
-        <translation type="unfinished"></translation>
+        <translation>Οι κωδικοποιητές έχουν ληφθεί και εγκατασταθεί με επιτυχία.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="282"/>
+        <location filename="../mainwindow.cpp" line="287"/>
         <source>Process finished. Errors have occurred during the installation.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="291"/>
-        <source>About MX Codecs</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="292"/>
-        <source>Version: </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="294"/>
-        <source>Simple codecs downloader for MX Linux</source>
-        <translation type="unfinished"></translation>
+        <translation>Η διαδικασία τελείωσε. Εμφανίστηκαν λάθη κατά την εγκατάσταση.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="296"/>
-        <source>Copyright (c) MX Linux</source>
-        <translation type="unfinished"></translation>
+        <source>About MX Codecs</source>
+        <translation>Περί του MX Κωδικοποιητές</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="297"/>
+        <location filename="../mainwindow.cpp" line="302"/>
         <source>%1 License</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="308"/>
+        <location filename="../mainwindow.cpp" line="313"/>
         <source>%1 Help</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>MX Codecs</source>
+        <translation type="vanished">MX Κωδικοποιητές</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="297"/>
+        <source>Version: </source>
+        <translation>Έκδοση: </translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="299"/>
+        <source>Simple codecs downloader for MX Linux</source>
+        <translation>Λήψη κωδικοποιητών για το MX Linux</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="301"/>
+        <source>Copyright (c) MX Linux</source>
+        <translation>Πνευματικά δικαιώματα (c) MX Linux</translation>
+    </message>
+    <message>
+        <source>License</source>
+        <translation type="vanished">Άδεια</translation>
+    </message>
+    <message>
+        <source>Changelog</source>
+        <translation type="vanished">Αρχείο αλλαγών</translation>
+    </message>
+    <message>
+        <source>&amp;Close</source>
+        <translation type="vanished">&amp;Κλείσιμο</translation>
+    </message>
+</context>
+<context>
+    <name>QApplication</name>
+    <message>
+        <source>Unable to get exclusive lock</source>
+        <translation type="vanished">Αδυναμία αποκλειστικού κλειδώματος</translation>
+    </message>
+    <message>
+        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
+        <translation type="vanished">Μια άλλη εφαρμογή διαχείρισης πακέτων (όπως το Synaptic ή η εντολή apt-get), βρίσκεται ήδη σε λειτουργία. Παρακαλώ κλείστε αυτή την εφαρμογή</translation>
+    </message>
+    <message>
+        <source>You must run this program as root.</source>
+        <translation type="vanished">Πρέπει να τρέξετε αυτή την εφαρμογή ως διαχειριστής.</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
         <location filename="../about.cpp" line="52"/>
         <source>License</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Άδεια</translation>
     </message>
     <message>
         <location filename="../about.cpp" line="53"/>
         <location filename="../about.cpp" line="62"/>
         <source>Changelog</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Αρχείο αλλαγών</translation>
     </message>
     <message>
         <location filename="../about.cpp" line="54"/>
         <source>Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Άκυρο</translation>
     </message>
     <message>
         <location filename="../about.cpp" line="74"/>
         <source>&amp;Close</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;Κλείσιμο</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="66"/>
         <source>Error</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Σφάλμα</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="67"/>
@@ -259,12 +290,12 @@
     <message>
         <location filename="../main.cpp" line="77"/>
         <source>Unable to get exclusive lock</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Αδυναμία αποκλειστικού κλειδώματος</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="78"/>
         <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Μια άλλη εφαρμογή διαχείρισης πακέτων (όπως το Synaptic ή η εντολή apt-get), βρίσκεται ήδη σε λειτουργία. Παρακαλώ κλείστε αυτή την εφαρμογή</translation>
     </message>
 </context>
 </TS>
