@@ -1,255 +1,286 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="fr_FR">
+<TS version="2.1" language="fr">
 <context>
     <name>MainWindow</name>
     <message>
         <location filename="../mainwindow.ui" line="14"/>
         <source>MX Codecs Installer</source>
-        <translation type="unfinished"></translation>
+        <translation>MX Installateur de Codecs</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="27"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some jurisdictions, their distribution may be limited. Please check the regulations in your area. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;Cette application vous permet d’installer des codecs non libres permettant des fonctions audio et vidéo avancées.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;Dans certaines juridictions, leur distribution doit être limitée afin que l’utilisateur puisse respecter les réglementations locales. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Êtes-vous prêt à assumer la responsabilité juridique du téléchargement de ces codecs ?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="44"/>
         <source>Downloading codecs files</source>
-        <translation type="unfinished"></translation>
+        <translation>Téléchargement des fichiers codecs</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="100"/>
         <source>Cancel any changes then quit</source>
-        <translation type="unfinished"></translation>
+        <translation>Annuler toutes les modifications puis quitter</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="103"/>
         <source>Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>Annuler</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="110"/>
         <source>Alt+N</source>
-        <translation type="unfinished"></translation>
+        <translation>Alt+N</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="129"/>
         <source>Begin codec download and installation</source>
-        <translation type="unfinished"></translation>
+        <translation>Démarrer le téléchargement et l’installation du codec</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="132"/>
         <source>OK</source>
-        <translation type="unfinished"></translation>
+        <translation>Valider</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="193"/>
         <source>About this application</source>
-        <translation type="unfinished"></translation>
+        <translation>À propos de cette application</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="196"/>
         <source>About...</source>
-        <translation type="unfinished"></translation>
+        <translation>À propos...</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="203"/>
         <source>Alt+B</source>
-        <translation type="unfinished"></translation>
+        <translation>Alt+B</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="232"/>
         <source>Display help </source>
-        <translation type="unfinished"></translation>
+        <translation>Afficher l’aide </translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="235"/>
         <source>Help</source>
-        <translation type="unfinished"></translation>
+        <translation>Aide</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="242"/>
         <source>Alt+H</source>
-        <translation type="unfinished"></translation>
+        <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="105"/>
-        <location filename="../mainwindow.cpp" line="146"/>
-        <location filename="../mainwindow.cpp" line="166"/>
-        <location filename="../mainwindow.cpp" line="209"/>
-        <location filename="../mainwindow.cpp" line="218"/>
-        <location filename="../mainwindow.cpp" line="241"/>
-        <location filename="../mainwindow.cpp" line="282"/>
+        <location filename="../mainwindow.cpp" line="184"/>
+        <location filename="../mainwindow.cpp" line="191"/>
+        <location filename="../mainwindow.cpp" line="200"/>
+        <location filename="../mainwindow.cpp" line="226"/>
+        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
+        <translation>&lt;b&gt;Commande en cours d’exécution...&lt;/b&gt;&lt;p&gt;</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="110"/>
+        <location filename="../mainwindow.cpp" line="151"/>
+        <location filename="../mainwindow.cpp" line="171"/>
+        <location filename="../mainwindow.cpp" line="214"/>
+        <location filename="../mainwindow.cpp" line="223"/>
+        <location filename="../mainwindow.cpp" line="246"/>
+        <location filename="../mainwindow.cpp" line="287"/>
         <source>Error</source>
-        <translation type="unfinished"></translation>
+        <translation>Erreur</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="106"/>
+        <location filename="../mainwindow.cpp" line="214"/>
+        <source>Cannot connect to the download site</source>
+        <translation>Vous ne pouvez pas vous connecter au site de téléchargement</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="126"/>
+        <source>Error downloading %1</source>
+        <translation>Erreur en téléchargeant %1</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="111"/>
         <source>Internet is not available, won&apos;t be able to download the list of packages</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="121"/>
-        <source>Error downloading %1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="147"/>
+        <location filename="../mainwindow.cpp" line="152"/>
         <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="166"/>
+        <location filename="../mainwindow.cpp" line="171"/>
         <source>Could not create temp directory. </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="179"/>
-        <location filename="../mainwindow.cpp" line="186"/>
-        <location filename="../mainwindow.cpp" line="195"/>
-        <location filename="../mainwindow.cpp" line="221"/>
-        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="179"/>
+        <location filename="../mainwindow.cpp" line="184"/>
         <source>downloading Packages.gz from &apos;main&apos;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="186"/>
+        <location filename="../mainwindow.cpp" line="191"/>
         <source>downloading Packages.gz from &apos;non-free&apos;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="195"/>
+        <location filename="../mainwindow.cpp" line="200"/>
         <source>downloading Packages.gz from i386 &apos;main&apos;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="201"/>
+        <location filename="../mainwindow.cpp" line="206"/>
         <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;b&gt;Téléchargement Terminé.&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="209"/>
-        <source>Cannot connect to the download site</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="218"/>
+        <location filename="../mainwindow.cpp" line="223"/>
         <source>Cannot connect find %1 package</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="238"/>
+        <location filename="../mainwindow.cpp" line="243"/>
         <source>Installing downloaded files</source>
-        <translation type="unfinished"></translation>
+        <translation>Installation des fichiers téléchargés</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="241"/>
+        <location filename="../mainwindow.cpp" line="246"/>
         <source>No downloaded *.debs files found.</source>
-        <translation type="unfinished"></translation>
+        <translation>Aucun fichier *. debs trouvé.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="259"/>
+        <location filename="../mainwindow.cpp" line="264"/>
         <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="261"/>
-        <source>Error installing %1</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;b&gt;Installation...&lt;/b&gt;&lt;p&gt;</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="266"/>
-        <source>Fix missing dependencies...</source>
-        <translation type="unfinished"></translation>
+        <source>Error installing %1</source>
+        <translation>Erreur lors de l’installation de %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="269"/>
-        <source>Error running %1 command</source>
-        <translation type="unfinished"></translation>
+        <location filename="../mainwindow.cpp" line="271"/>
+        <source>Fix missing dependencies...</source>
+        <translation>Réparation des dépendances manquantes...</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="274"/>
-        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="278"/>
-        <source>Finished</source>
-        <translation type="unfinished"></translation>
+        <source>Error running %1 command</source>
+        <translation>Erreur lors de l’activation de la commande %1</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="279"/>
+        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
+        <translation>&lt;b&gt;Le processus d’installation est terminé&lt;/b&gt;</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="283"/>
+        <source>Finished</source>
+        <translation>Terminé</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="284"/>
         <source>Codecs files have been downloaded and installed successfully.</source>
-        <translation type="unfinished"></translation>
+        <translation>les fichiers Codecs ont été téléchargés et installés avec succès.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="282"/>
+        <location filename="../mainwindow.cpp" line="287"/>
         <source>Process finished. Errors have occurred during the installation.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="291"/>
-        <source>About MX Codecs</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="292"/>
-        <source>Version: </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="294"/>
-        <source>Simple codecs downloader for MX Linux</source>
-        <translation type="unfinished"></translation>
+        <translation>Processus terminé. Des erreurs se sont produites lors de l’installation.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="296"/>
-        <source>Copyright (c) MX Linux</source>
-        <translation type="unfinished"></translation>
+        <source>About MX Codecs</source>
+        <translation>À propos de MX Codecs</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="297"/>
+        <location filename="../mainwindow.cpp" line="302"/>
         <source>%1 License</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="308"/>
+        <location filename="../mainwindow.cpp" line="313"/>
         <source>%1 Help</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>MX Codecs</source>
+        <translation type="vanished">MX Codecs</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="297"/>
+        <source>Version: </source>
+        <translation>Version : </translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="299"/>
+        <source>Simple codecs downloader for MX Linux</source>
+        <translation>Simple gestionnaire de téléchargement de codecs pour MX Linux</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="301"/>
+        <source>Copyright (c) MX Linux</source>
+        <translation>Copyright (c) MX Linux</translation>
+    </message>
+    <message>
+        <source>License</source>
+        <translation type="vanished">Licence</translation>
+    </message>
+    <message>
+        <source>Changelog</source>
+        <translation type="vanished">Journal des modifications</translation>
+    </message>
+    <message>
+        <source>&amp;Close</source>
+        <translation type="vanished">&amp;Quitter</translation>
+    </message>
+</context>
+<context>
+    <name>QApplication</name>
+    <message>
+        <source>Unable to get exclusive lock</source>
+        <translation type="vanished">Impossible d’obtenir le verrou exclusif</translation>
+    </message>
+    <message>
+        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
+        <translation type="vanished">Une autre application de gestion des paquets (comme Synaptic ou apt-get) est déjà en cours d’exécution. Veuillez d’abord fermer cette application.</translation>
+    </message>
+    <message>
+        <source>You must run this program as root.</source>
+        <translation type="vanished">Vous devez exécuter cette application en tant qu’administrateur.</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
         <location filename="../about.cpp" line="52"/>
         <source>License</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Licence</translation>
     </message>
     <message>
         <location filename="../about.cpp" line="53"/>
         <location filename="../about.cpp" line="62"/>
         <source>Changelog</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Journal des modifications</translation>
     </message>
     <message>
         <location filename="../about.cpp" line="54"/>
         <source>Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Annuler</translation>
     </message>
     <message>
         <location filename="../about.cpp" line="74"/>
         <source>&amp;Close</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;Quitter</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="66"/>
         <source>Error</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Erreur</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="67"/>
@@ -259,12 +290,12 @@
     <message>
         <location filename="../main.cpp" line="77"/>
         <source>Unable to get exclusive lock</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Impossible d’obtenir le verrou exclusif</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="78"/>
         <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Une autre application de gestion des paquets (comme Synaptic ou apt-get) est déjà en cours d’exécution. Veuillez d’abord fermer cette application.</translation>
     </message>
 </context>
 </TS>
